@@ -4,8 +4,6 @@
 //! communicate via unreliable WebRTC datachannels
 
 #![deny(
-    missing_docs,
-    missing_debug_implementations,
     trivial_casts,
     trivial_numeric_casts,
     unstable_features,
@@ -18,21 +16,24 @@ extern crate log;
 #[macro_use]
 extern crate cfg_if;
 
-pub use naia_socket_shared::LinkConditionerConfig;
-
+mod async_socket;
 mod error;
 mod impls;
-mod link_conditioner;
-mod message_sender;
 mod packet;
-mod server_socket_trait;
+mod packet_receiver;
+mod packet_sender;
+mod server_addrs;
+mod socket;
+
+/// Executor for Server
+pub mod executor;
 
 pub use error::NaiaServerSocketError;
-pub use impls::ServerSocket;
-pub use message_sender::MessageSender;
-pub use naia_socket_shared::find_my_ip_address;
 pub use packet::Packet;
-pub use server_socket_trait::ServerSocketTrait;
+pub use packet_receiver::PacketReceiver;
+pub use packet_sender::PacketSender;
+pub use server_addrs::ServerAddrs;
+pub use socket::Socket;
 
 cfg_if! {
     if #[cfg(all(feature = "use-udp", feature = "use-webrtc"))]
